@@ -29,9 +29,10 @@ class DataSource(Singleton, RedisDelegate, MongoDelegate, MySQLDelegate):
         inst = cls()
 
         await inst.async_init_redis(
-            host=ConfigStatic.RedisHost[0], port=ConfigStatic.RedisHost[1], password=ConfigStatic.RedisPasswd,
-            db_base=ConfigStatic.RedisBase, max_connections=ConfigStatic.RedisMaxConn,
-            default_expire=ConfigStatic.RedisExpire, key_prefix=ConfigStatic.RedisKeyPrefix
+            ConfigStatic.RedisHost, ConfigStatic.RedisPasswd,
+            minsize=ConfigStatic.RedisMinConn, maxsize=ConfigStatic.RedisMaxConn,
+            db=ConfigStatic.RedisBase, expire=ConfigStatic.RedisExpire,
+            key_prefix=ConfigStatic.RedisKeyPrefix
         )
 
         await inst.async_init_mongo(
@@ -115,6 +116,6 @@ class ServiceBase(Singleton, Utils):
 
         return REQUEST_ID_CONTEXT.get(None)
 
-    def Break(self, data=None, layers=1):
+    def Break(self, *args, layers=1):
 
-        raise Ignore(data, layers)
+        raise Ignore(*args, layers=layers)
