@@ -68,6 +68,13 @@ class Utils(base.Utils):
         for _ in range(max(1, count)):
             yield
 
+    @staticmethod
+    def get_event_loop():
+        """获取当前loop
+        """
+
+        return asyncio.events.get_event_loop()
+
     @staticmethod
     def loop_time():
         """获取当前loop内部时钟
@@ -84,6 +91,11 @@ class Utils(base.Utils):
 
         loop = asyncio.events.get_event_loop()
 
+        if r'context' in kwargs:
+            context = kwargs.pop(r'context')
+        else:
+            context = Context()
+
         if kwargs:
 
             return loop.call_soon(
@@ -94,7 +106,7 @@ class Utils(base.Utils):
                         **kwargs
                     )
                 ),
-                context=Context()
+                context=context
             )
 
         else:
@@ -102,7 +114,7 @@ class Utils(base.Utils):
             return loop.call_soon(
                 async_adapter(callback),
                 *args,
-                context=Context()
+                context=context
             )
 
     @classmethod
@@ -112,6 +124,11 @@ class Utils(base.Utils):
 
         loop = asyncio.events.get_event_loop()
 
+        if r'context' in kwargs:
+            context = kwargs.pop(r'context')
+        else:
+            context = Context()
+
         if kwargs:
 
             return loop.call_soon_threadsafe(
@@ -122,7 +139,7 @@ class Utils(base.Utils):
                         **kwargs
                     )
                 ),
-                context=Context()
+                context=context
             )
 
         else:
@@ -130,7 +147,7 @@ class Utils(base.Utils):
             return loop.call_soon_threadsafe(
                 async_adapter(callback),
                 *args,
-                context=Context()
+                context=context
             )
 
     @classmethod
@@ -140,6 +157,11 @@ class Utils(base.Utils):
 
         loop = asyncio.events.get_event_loop()
 
+        if r'context' in kwargs:
+            context = kwargs.pop(r'context')
+        else:
+            context = Context()
+
         if kwargs:
 
             return loop.call_later(
@@ -151,7 +173,7 @@ class Utils(base.Utils):
                         **kwargs
                     )
                 ),
-                context=Context()
+                context=context
             )
 
         else:
@@ -160,7 +182,7 @@ class Utils(base.Utils):
                 delay,
                 async_adapter(callback),
                 *args,
-                context=Context()
+                context=context
             )
 
     @classmethod
@@ -170,6 +192,11 @@ class Utils(base.Utils):
 
         loop = asyncio.events.get_event_loop()
 
+        if r'context' in kwargs:
+            context = kwargs.pop(r'context')
+        else:
+            context = Context()
+
         if kwargs:
 
             return loop.call_at(
@@ -181,7 +208,7 @@ class Utils(base.Utils):
                         **kwargs
                     )
                 ),
-                context=Context()
+                context=context
             )
 
         else:
@@ -190,7 +217,7 @@ class Utils(base.Utils):
                 when,
                 async_adapter(callback),
                 *args,
-                context=Context()
+                context=context
             )
 
     @staticmethod
@@ -584,13 +611,13 @@ class AsyncContextManager:
 
         await self._context_release()
 
-        if exc_type is base.Ignore:
+        if exc_type and issubclass(exc_type, base.Ignore):
 
             return not exc_value.throw()
 
         elif exc_value:
 
-            Utils.log.exception(traceback.format_exc())
+            Utils.log.exception(exc_value)
 
             return True
 
