@@ -3,6 +3,7 @@
 __author__ = r'wsb310@gmail.com'
 
 import os
+import sys
 import asyncio
 
 from hagworm import hagworm_slogan
@@ -10,73 +11,126 @@ from hagworm import __version__ as hagworm_version
 
 from hagworm.extend.base import catch_error
 from hagworm.extend.process import fork_processes
-from hagworm.extend.asyncio.base import install_uvloop, Utils, AsyncCirculator
-from hagworm.extend.asyncio.buffer import DataAsyncQueue
+from hagworm.extend.asyncio.base import install_uvloop, Utils
 from hagworm.extend.logging import DEFAULT_LOG_FILE_ROTATOR
 from hagworm.extend.interface import FunctorInterface, RunnableInterface
 from hagworm.extend.asyncio.zmq import Push, Pull
 
 
 SIGNAL_PROTOCOL = r'tcp'
-SIGNAL_PORT_1 = 0x310
-SIGNAL_PORT_2 = 0x601
+SIGNAL_PORT_1 = 83310
+SIGNAL_PORT_2 = 10601
 
 
 class Daemon(FunctorInterface):
 
-    def __init__(self):
+    def __init__(self, child_num=2, keep_alive=False):
 
-        self._pids = None
+        if child_num < 2:
+            raise ValueError(r'child_num cannot be less than 2')
 
-    def _check_pids(self):
+        self._child_num = child_num
+        self._keep_alive = keep_alive
+
+        self._pids = set()
+
+    def is_active(self):
+
+        return self._child_num != 0 and len(self._pids) != 0
+
+    def _fork_processes(self):
+
+        while len(self._pids) < self._child_num:
+
+            pid = fork_processes()
+
+            if pid == 0:
+                self._child_num = 0
+                return False
+
+            self._pids.add(pid)
+
+        return True
+
+    def _check_processes(self):
 
         for pid in self._pids.copy():
-            if os.waitpid(pid, os.WNOHANG)[0] == pid:
-                self._pids.remove(pid)
 
-        return len(self._pids) == 0
+            if os.waitpid(pid, os.WNOHANG)[0] != pid:
+                continue
 
-    async def _run(self):
+            self._pids.remove(pid)
 
-        async for _ in AsyncCirculator():
-            if self._check_pids():
-                break
+            if self._keep_alive:
+                self._fork_processes()
 
-    def __call__(self, pids):
+    def _run(self):
 
-        self._pids = set(pids)
+        while True:
 
-        Utils.run_until_complete(self._run())
+            self._check_processes()
+
+            if not self.is_active():
+                return
+
+    def __call__(self):
+
+        if self._fork_processes():
+            self._run()
+            sys.exit(0)
 
 
-_DEFAULT_DAEMON = Daemon()
+class MainProcessAbstract(Daemon):
 
+    def __init__(self, child_num=2):
 
-class MainProcessAbstract(Daemon, DataAsyncQueue):
-
-    def __init__(self):
-
-        Daemon.__init__(self)
-        DataAsyncQueue.__init__(self)
+        Daemon.__init__(self, child_num, False)
 
         global SIGNAL_PROTOCOL, SIGNAL_PORT_1, SIGNAL_PORT_2
 
         self._push_server = Push(f'{SIGNAL_PROTOCOL}://*:{SIGNAL_PORT_1}', True)
         self._pull_server = Pull(f'{SIGNAL_PROTOCOL}://*:{SIGNAL_PORT_2}', True)
 
-    def __call__(self, pids):
+    async def _handle_message(self, message):
+        raise NotImplementedError()
+
+    async def _recv_message(self):
+
+        while True:
+
+            message = await self._pull_server.recv(True)
+
+            if message is None:
+                break
+            else:
+                await self._handle_message(message)
+
+    async def _run(self):
+
+        while True:
+
+            self._check_processes()
+
+            if self.is_active():
+                await self._recv_message()
+            else:
+                break
+
+    def __call__(self):
+
+        if not self._fork_processes():
+            return
 
         self._push_server.open()
         self._pull_server.open()
 
         with catch_error():
-            super().__call__(pids)
+            Utils.run_until_complete(self._run())
 
         self._push_server.close()
         self._pull_server.close()
 
-    async def _handle_data(self, data):
-        raise NotImplementedError()
+        sys.exit(0)
 
 
 class ChildProcessAbstract(FunctorInterface):
@@ -88,11 +142,9 @@ class ChildProcessAbstract(FunctorInterface):
         self._push_client = Push(f'{SIGNAL_PROTOCOL}://localhost:{SIGNAL_PORT_2}')
         self._pull_client = Pull(f'{SIGNAL_PROTOCOL}://localhost:{SIGNAL_PORT_1}')
 
-        self._process_id = None
+        self._process_id = Utils.getpid()
 
-    async def __call__(self, process_id):
-
-        self._process_id = process_id
+    async def __call__(self):
 
         self._push_client.open()
         self._pull_client.open()
@@ -117,11 +169,9 @@ class Launcher(RunnableInterface):
     def __init__(self,
                  log_file_path=None, log_level=r'INFO',
                  log_file_rotation=DEFAULT_LOG_FILE_ROTATOR, log_file_retention=0xff,
-                 subprocess=1, daemon=_DEFAULT_DAEMON, debug=False
+                 daemon=None, debug=False
                  ):
 
-        self._process_id = 0
-
         if log_file_path:
 
             _log_file_path = Utils.path.join(
@@ -153,16 +203,18 @@ class Launcher(RunnableInterface):
 
         install_uvloop()
 
-        if subprocess > 1:
-            self._process_id = fork_processes(subprocess, daemon)
+        if daemon:
+            daemon()
 
         self._event_loop = asyncio.get_event_loop()
         self._event_loop.set_debug(debug)
 
     def run(self, func, *args, **kwargs):
 
-        Utils.log.success(f'Start process no.{self._process_id}')
+        pid = Utils.getpid()
 
-        self._event_loop.run_until_complete(func(self._process_id, *args, **kwargs))
+        Utils.log.success(f'Start process pid.{pid}')
 
-        Utils.log.success(f'Stop process no.{self._process_id}')
+        self._event_loop.run_until_complete(func(*args, **kwargs))
+
+        Utils.log.success(f'Stop process pid.{pid}')
