@@ -4,6 +4,7 @@ __author__ = r'wsb310@gmail.com'
 
 import asyncio
 import aiomysql
+import sqlalchemy
 
 from aiomysql.sa import SAConnection, Engine
 from aiomysql.sa.engine import _dialect as dialect
@@ -57,8 +58,11 @@ class MongoPool:
         for server in self._servers.values():
             server.pool.remove_stale_sockets()
 
+        self._pool_options = self._pool.options.pool_options
+
         Utils.log.info(
-            f"Mongo {host} ({self._name}) initialized: {self._pool.min_pool_size}/{self._pool.max_pool_size}"
+            f"Mongo {host} ({self._name}) initialized: "
+            f"{self._pool_options.min_pool_size}/{self._pool_options.max_pool_size}"
         )
 
     @property
@@ -72,17 +76,19 @@ class MongoPool:
 
         for address, server in self._servers.items():
 
-            poll_size = len(server.pool.sockets) + server.pool.active_sockets
+            free_size = len(server.pool.sockets)
+            pool_size = free_size + server.pool.active_sockets
+            max_pool_size = server.pool.max_pool_size
 
-            if (self._pool.max_pool_size - poll_size) < MONGO_POLL_WATER_LEVEL_WARNING_LINE:
+            if (max_pool_size - server.pool.active_sockets) < MONGO_POLL_WATER_LEVEL_WARNING_LINE:
                 Utils.log.warning(
                     f'Mongo connection pool not enough ({self._name}){address}: '
-                    f'{poll_size}/{self._pool.max_pool_size}'
+                    f'{free_size}({pool_size}/{max_pool_size})'
                 )
             else:
                 Utils.log.debug(
                     f'Mongo connection pool info ({self._name}){address}: '
-                    f'{poll_size}/{self._pool.max_pool_size}'
+                    f'{free_size}({pool_size}/{max_pool_size})'
                 )
 
     def reset(self):
@@ -504,11 +510,6 @@ class _ClientBase:
 
         self._lock = asyncio.Lock()
 
-    def __del__(self):
-
-        if self._conn is not None:
-            Utils.log.critical(r'Mysql connection leak')
-
     @property
     def readonly(self):
 
@@ -620,9 +621,14 @@ class _ClientBase:
 
         return result
 
-    async def count(self, query, *multiparams, **params):
+    async def count(self, table_col, select_where=None):
 
-        result = await self.find(query, *multiparams, **params)
+        _select = sqlalchemy.select([sqlalchemy.func.count(table_col).label(r'tbl_row_count')])
+
+        if select_where is not None:
+            _select = _select.where(select_where)
+
+        result = await self.find(_select)
 
         return result[r'tbl_row_count']
 
