@@ -117,21 +117,26 @@ class Publish(_SocketBase):
         super().__init__(name, zmq.PUB, address, bind_mode)
 
 
-class PublishWithBuffer(_SocketBase, QueueBuffer):
+class PublishWithBuffer(_SocketBase):
 
-    def __init__(self, address, bind_mode=False, *, name=None, buffer_maxsize=0xffff, buffer_timeout=1):
+    def __init__(self, address, bind_mode=False, *, name=None, buffer_slice_size=0xffff, buffer_timeout=1):
 
         _SocketBase.__init__(self, name, zmq.PUB, address, bind_mode)
-        QueueBuffer.__init__(self, buffer_maxsize, buffer_timeout)
 
-    async def _run(self, data_list):
+        self._buffer = QueueBuffer(self._handle_data, buffer_slice_size, buffer_timeout)
 
-        await self._socket.send_pyobj(data_list)
+    async def _handle_data(self, data):
+
+        await self._socket.send_pyobj(data)
+
+    def send(self, data):
+
+        self._buffer.append(data)
 
     async def safe_close(self, timeout=0):
 
         async for _ in AsyncCirculator(timeout):
-            if len(self._data_list) == 0:
+            if self._buffer.size() == 0:
                 super().close()
                 break
 
