@@ -24,6 +24,7 @@ import psutil
 import functools
 import binascii
 import ujson
+import msgpack
 import zlib
 import socket
 import struct
@@ -88,6 +89,11 @@ class Utils:
 
     date_parse = staticmethod(date_parse)
 
+    @classmethod
+    def get_class_name(cls, val):
+
+        return f'{val.__module__}.{val.__name__}'
+
     @classmethod
     def environment(cls):
 
@@ -153,6 +159,16 @@ class Utils:
 
         return ujson.loads(cls.basestring(val), **kwargs)
 
+    @classmethod
+    def msgpack_encode(cls, val, **kwargs):
+
+        return msgpack.dumps(val, **kwargs)
+
+    @classmethod
+    def msgpack_decode(cls, val, **kwargs):
+
+        return msgpack.loads(val, **kwargs)
+
     @classmethod
     def today(cls):
 
@@ -975,21 +991,21 @@ class Ignore(BaseError):
 
     """
 
-    def __init__(self, data=None, layers=1):
+    def __init__(self, *args, layers=1, **kwargs):
 
-        super().__init__(data)
+        super().__init__(*args, **kwargs)
 
         self._layers = layers
 
-        if self._data:
-            Utils.log.warning(self._data)
+        if err := str(self):
+            Utils.log.warning(err)
 
     def throw(self):
 
         if self._layers > 0:
             self._layers -= 1
 
-        return self._layers > 0
+        return self._layers != 0
 
 
 @contextmanager
@@ -1043,10 +1059,6 @@ class ContextManager:
 
     """
 
-    def __del__(self):
-
-        self._context_release()
-
     def __enter__(self):
 
         self._context_initialize()
