@@ -6,20 +6,9 @@ __author__ = r'wsb310@gmail.com'
 # 基础异常
 class BaseError(Exception):
 
-    def __init__(self, data=None):
+    def __init__(self, *args, **kwargs):
 
-        super().__init__()
-
-        self._data = data
-
-    @property
-    def data(self):
-
-        return self._data
-
-    def __repr__(self):
-
-        return repr(self._data)
+        super().__init__(*args, **kwargs)
 
 
 # 数据库只读限制异常
