@@ -3,6 +3,7 @@
 __author__ = r'wsb310@gmail.com'
 
 import os
+import sys
 import queue
 import logging
 
@@ -72,15 +73,13 @@ class QueuedFileSink(FileSink):
     """日志文件队列
     """
 
-    def __init__(self, path, *, buffer_size=0, buffer_block=False, **kwargs):
+    def __init__(self, path, *, buffer_maxsize=0xffff, **kwargs):
 
         super().__init__(path, **kwargs)
 
-        self._buffer = queue.Queue(buffer_size)
-        self._buffer_size = buffer_size
-        self._buffer_block = buffer_block
+        self._buffer = queue.Queue(buffer_maxsize)
 
-        self._worker = Thread(target=self._queued_writer, daemon=True)
+        self._worker = Thread(target=self._queued_writer)
         self._running = True
 
         self._worker.start()
@@ -88,9 +87,10 @@ class QueuedFileSink(FileSink):
     def write(self, message):
 
         try:
-            self._buffer.put(message, block=self._buffer_block)
+            self._buffer.put(message, block=True, timeout=1)
         except queue.Full as _:
-            print(f'Log queued writer overflow: {self._buffer_size}')
+            if message.record[r'level'].no > logging.INFO:
+                sys.stderr.write(message)
 
     def stop(self):
 
@@ -104,9 +104,9 @@ class QueuedFileSink(FileSink):
         while self._running:
 
             try:
-                message = self._buffer.get(block=True, timeout=1)
-                if message:
-                    super().write(message)
+                super().write(
+                    self._buffer.get(block=True, timeout=1)
+                )
             except queue.Empty as _:
                 pass
 
@@ -123,9 +123,9 @@ def init_logger(
 
     level = level.upper()
 
-    if handler or file_path:
+    Utils.log.remove()
 
-        Utils.log.remove()
+    if handler or file_path:
 
         if handler:
             Utils.log.add(
@@ -152,7 +152,12 @@ def init_logger(
 
     else:
 
-        Utils.log.level(level)
+        Utils.log.add(
+            sys.stderr,
+            level=level,
+            enqueue=True,
+            backtrace=debug
+        )
 
     logger = logging.getLogger()
     logger.setLevel(level)
