@@ -9,6 +9,7 @@ from pydantic.fields import ModelField
 
 from hagworm.extend import validator
 from hagworm.extend.base import Utils
+from hagworm.extend.struct import Enum
 
 
 class _EnumKeyTypeBase(str):
@@ -36,7 +37,7 @@ def EnumKeyType(enum):
     if enum not in _EnumKeyTypeBase.__subclasses__:
 
         _EnumKeyTypeBase.__subclasses__[enum] = type(
-            r'EnumKeyType_{0}'.format(enum.__name__),
+            f'EnumKeyType_{Utils.get_class_name(enum)}',
             (_EnumKeyTypeBase,),
             {r'Enum': enum}
         )
@@ -44,9 +45,10 @@ def EnumKeyType(enum):
     return _EnumKeyTypeBase.__subclasses__.get(enum)
 
 
-class _EnumValueTypeBase(int):
+class _EnumValueTypeBase:
 
     __subclasses__ = {}
+    __value_type__ = None
 
     @classmethod
     def __get_validators__(cls):
@@ -58,12 +60,8 @@ class _EnumValueTypeBase(int):
         if field.required is False and val == field.default:
             return val
 
-        if isinstance(val, int):
-            pass
-        elif val.isdigit():
-            val = int(val)
-        else:
-            raise errors.EnumMemberError(enum_values=cls.Enum)
+        if not isinstance(val, cls.__value_type__):
+            val = cls.__value_type__(val)
 
         if not cls.Enum.has_value(val):
             raise errors.EnumMemberError(enum_values=cls.Enum)
@@ -71,16 +69,20 @@ class _EnumValueTypeBase(int):
         return val
 
 
-def EnumValueType(enum):
+def EnumValueType(enum: Enum):
 
     if enum not in _EnumValueTypeBase.__subclasses__:
 
-        _EnumValueTypeBase.__subclasses__[enum] = type(
-            r'EnumValueType_{0}'.format(enum.__name__),
-            (_EnumValueTypeBase,),
+        value_type = type(list(enum.values())[0])
+
+        cls = _EnumValueTypeBase.__subclasses__[enum] = type(
+            f'EnumValueType_{Utils.get_class_name(enum)}',
+            (_EnumValueTypeBase, value_type),
             {r'Enum': enum}
         )
 
+        cls.__value_type__ = value_type
+
     return _EnumValueTypeBase.__subclasses__.get(enum)
 
 
@@ -152,12 +154,32 @@ class DateType(str):
 
         try:
             val = Utils.date_parse(val)
-        except ValueError:
+        except Exception:
             raise errors.DateError()
 
         return val
 
 
+class JsonType(str):
+
+    @classmethod
+    def __get_validators__(cls):
+        yield cls.validate
+
+    @classmethod
+    def validate(cls, val: Any, field: ModelField) -> Any:
+
+        if field.required is False and val == field.default:
+            return val
+
+        try:
+            val = Utils.json_decode(val)
+        except Exception:
+            raise errors.JsonError()
+
+        return val
+
+
 class IntListType(str):
 
     @classmethod
@@ -172,7 +194,7 @@ class IntListType(str):
 
         try:
             val = Utils.split_int(val)
-        except ValueError:
+        except Exception:
             raise errors.ListError()
 
         return val
@@ -192,7 +214,7 @@ class FloatListType(str):
 
         try:
             val = Utils.split_float(val)
-        except ValueError:
+        except Exception:
             raise errors.ListError()
 
         return val
