@@ -4,6 +4,7 @@ __author__ = r'wsb310@gmail.com'
 
 from fastapi.responses import UJSONResponse
 
+from hagworm.extend.base import Ignore
 from hagworm.extend.struct import Result
 
 from .middleware import RequestIDMiddleware
@@ -24,18 +25,18 @@ class Response(UJSONResponse):
         )
 
 
-class ErrorResponse(Response, Exception):
+class ErrorResponse(Response, Ignore):
 
-    def __init__(self, error_code, content=None, status_code=200, **kwargs):
+    def __init__(self, code, content=None, status_code=200, **kwargs):
 
-        self._error_code = error_code
+        self._code = code
 
         Response.__init__(self, content, status_code, **kwargs)
-        Exception.__init__(self, self.body.decode())
+        Ignore.__init__(self, self.body.decode(), layers=-1)
 
     def render(self, content):
 
         return UJSONResponse.render(
             self,
-            Result(code=self._error_code, data=content, request_id=self._request_id)
+            Result(code=self._code, error=content, request_id=self._request_id)
         )
