@@ -2,6 +2,8 @@
 
 __author__ = r'wsb310@gmail.com'
 
+import sys
+
 from terminal_table import Table
 
 from hagworm.extend.logging import DEFAULT_LOG_FILE_ROTATOR
@@ -12,29 +14,36 @@ from hagworm.extend.asyncio.zmq import Subscribe, PublishWithBuffer
 
 
 SIGNAL_PROTOCOL = r'tcp'
-SIGNAL_PORT = 0x601
+SIGNAL_PORT = 83310
 HIGH_WATER_MARK = 0xffffff
 
 
 class Daemon(command.Daemon):
 
+    def __init__(self, child_num=2):
+
+        super().__init__(child_num, False)
+
     async def _run(self):
 
         with Reporter() as reporter:
 
             async for _ in AsyncCirculator():
 
-                stopped = self._check_pids()
+                self._check_processes()
+
+                if not self.is_active():
+                    break
 
                 await reporter.handle_message()
 
-                if stopped:
-                    break
-
             Utils.log.info(f'\n{reporter.get_report_table()}')
 
+    def __call__(self):
 
-_DEFAULT_DAEMON = Daemon()
+        if self._fork_processes():
+            Utils.run_until_complete(self._run())
+            sys.exit(0)
 
 
 class Launcher(command.Launcher):
@@ -42,12 +51,12 @@ class Launcher(command.Launcher):
     def __init__(self,
                  log_file_path=None, log_level=r'INFO',
                  log_file_rotation=DEFAULT_LOG_FILE_ROTATOR, log_file_retention=0xff,
-                 subprocess=1, daemon=_DEFAULT_DAEMON, debug=False
+                 daemon=None, debug=False
                  ):
 
         super().__init__(
             log_file_path, log_level, log_file_rotation, log_file_retention,
-            subprocess, daemon, debug
+            daemon, debug
         )
 
 
@@ -133,13 +142,13 @@ class TaskInterface(Utils, RunnableInterface):
 
     def success(self, name: str, resp_time: int):
 
-        self._publisher.append(
+        self._publisher.send(
             (name, r'success', resp_time,)
         )
 
     def failure(self, name: str, resp_time: int):
 
-        self._publisher.append(
+        self._publisher.send(
             (name, r'failure', resp_time,)
         )
 
@@ -156,7 +165,7 @@ class Runner(Utils, FunctorInterface):
         self._task_cls = task_cls
         self._publisher = PublishWithBuffer(f'{SIGNAL_PROTOCOL}://localhost:{SIGNAL_PORT}', False)
 
-    async def __call__(self, process_id, times, task_num):
+    async def __call__(self, times, task_num):
 
         self._publisher.open()
 
